===========================
 Invenio-Webhooks v1.0.0a1
===========================

Invenio-Webhooks v1.0.0a1 was released on January 6, 2016.

About
-----

Invenio module for processing webhook events.

*This is an experimental developer preview release.*

What's new
----------

- Port to new structure for Invenio 3.

Installation
------------

   $ pip install invenio-webhooks==1.0.0a1

Documentation
-------------

   http://pythonhosted.org/invenio-webhooks/

Happy hacking and thanks for flying Invenio-Webhooks.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-webhooks
|   URL: http://invenio-software.org
